@@ -41,13 +41,13 @@ extern "C"
 {
 #endif
 
-#define LIBGNUTLS_VERSION "2.4.0"
+#define LIBGNUTLS_VERSION "2.6.6"
 
 #define LIBGNUTLS_VERSION_MAJOR 2
-#define LIBGNUTLS_VERSION_MINOR 4
-#define LIBGNUTLS_VERSION_PATCH 0
+#define LIBGNUTLS_VERSION_MINOR 6
+#define LIBGNUTLS_VERSION_PATCH 6
 
-#define LIBGNUTLS_VERSION_NUMBER 0x020400
+#define LIBGNUTLS_VERSION_NUMBER 0x020606
 
 
 
@@ -79,7 +79,19 @@ extern "C"
     GNUTLS_CIPHER_CAMELLIA_128_CBC,
     GNUTLS_CIPHER_CAMELLIA_256_CBC,
     GNUTLS_CIPHER_RC2_40_CBC = 90,
-    GNUTLS_CIPHER_DES_CBC
+    GNUTLS_CIPHER_DES_CBC,
+
+    /* used only for PGP internals. Ignored in TLS/SSL 
+     */
+    GNUTLS_CIPHER_IDEA_PGP_CFB = 200,
+    GNUTLS_CIPHER_3DES_PGP_CFB,
+    GNUTLS_CIPHER_CAST5_PGP_CFB,
+    GNUTLS_CIPHER_BLOWFISH_PGP_CFB,
+    GNUTLS_CIPHER_SAFER_SK128_PGP_CFB,
+    GNUTLS_CIPHER_AES128_PGP_CFB,
+    GNUTLS_CIPHER_AES192_PGP_CFB,
+    GNUTLS_CIPHER_AES256_PGP_CFB,
+    GNUTLS_CIPHER_TWOFISH_PGP_CFB
   } gnutls_cipher_algorithm_t;
 
   typedef enum
@@ -239,7 +251,13 @@ extern "C"
      */
     GNUTLS_CERT_SIGNER_NOT_FOUND = 64,
     GNUTLS_CERT_SIGNER_NOT_CA = 128,
-    GNUTLS_CERT_INSECURE_ALGORITHM = 256
+    GNUTLS_CERT_INSECURE_ALGORITHM = 256,
+
+    /* Time verification.
+     */
+    GNUTLS_CERT_NOT_ACTIVATED = 512,
+    GNUTLS_CERT_EXPIRED = 1024
+
   } gnutls_certificate_status_t;
 
   typedef enum
@@ -287,7 +305,7 @@ extern "C"
     {
       GNUTLS_CRT_PRINT_FULL,
       GNUTLS_CRT_PRINT_ONELINE,
-      GNUTLS_CRT_PRINT_UNSIGNED_FULL,
+      GNUTLS_CRT_PRINT_UNSIGNED_FULL
     } gnutls_certificate_print_formats_t;
 
   typedef enum
@@ -396,6 +414,8 @@ extern "C"
   const char *gnutls_kx_get_name (gnutls_kx_algorithm_t algorithm);
   const char *gnutls_certificate_type_get_name (gnutls_certificate_type_t
 						type);
+  const char *gnutls_pk_get_name (gnutls_pk_algorithm_t algorithm);
+  const char *gnutls_sign_get_name (gnutls_sign_algorithm_t algorithm);
 
   gnutls_mac_algorithm_t gnutls_mac_get_id (const char* name);
   gnutls_compression_method_t gnutls_compression_get_id (const char* name);
@@ -403,7 +423,8 @@ extern "C"
   gnutls_kx_algorithm_t gnutls_kx_get_id (const char* name);
   gnutls_protocol_t gnutls_protocol_get_id (const char* name);
   gnutls_certificate_type_t gnutls_certificate_type_get_id (const char* name);
-
+  gnutls_pk_algorithm_t gnutls_pk_get_id (const char *name);
+  gnutls_sign_algorithm_t gnutls_sign_get_id (const char *name);
 
   /* list supported algorithms */
   const gnutls_cipher_algorithm_t *gnutls_cipher_list (void);
@@ -412,6 +433,8 @@ extern "C"
   const gnutls_protocol_t *gnutls_protocol_list (void);
   const gnutls_certificate_type_t *gnutls_certificate_type_list (void);
   const gnutls_kx_algorithm_t *gnutls_kx_list (void);
+  const gnutls_pk_algorithm_t *gnutls_pk_list (void);
+  const gnutls_sign_algorithm_t *gnutls_sign_list (void);
   const char *gnutls_cipher_suite_info (size_t i,
 					char *id,
 					gnutls_kx_algorithm_t *kx,
@@ -425,6 +448,7 @@ extern "C"
 
   void gnutls_perror (int error);
   const char *gnutls_strerror (int error);
+  const char *gnutls_strerror_name (int error);
 
 /* Semi-internal functions.
  */
@@ -468,6 +492,29 @@ extern "C"
 
 /* TLS Extensions */
 
+  typedef int (*gnutls_ext_recv_func) (gnutls_session_t session,
+				       const unsigned char *data, size_t len);
+  typedef int (*gnutls_ext_send_func) (gnutls_session_t session,
+				       unsigned char *data, size_t len);
+
+  /* This flag indicates for an extension whether
+   * it is useful to application level or TLS level only.
+   * This is (only) used to parse the application level extensions
+   * before the user_hello callback is called.
+   */
+  typedef enum
+    {
+      GNUTLS_EXT_ANY,
+      GNUTLS_EXT_APPLICATION,
+      GNUTLS_EXT_TLS
+    } gnutls_ext_parse_type_t;
+
+  int gnutls_ext_register (int type,
+			   const char *name,
+			   gnutls_ext_parse_type_t parse_type,
+			   gnutls_ext_recv_func recv_func,
+			   gnutls_ext_send_func send_func);
+
   typedef enum
   {
     GNUTLS_NAME_DNS = 1
@@ -567,12 +614,21 @@ extern "C"
 /* returns security values. 
  * Do not use them unless you know what you're doing.
  */
-#define TLS_MASTER_SIZE 48
-#define TLS_RANDOM_SIZE 32
+#define GNUTLS_MASTER_SIZE 48
+#define GNUTLS_RANDOM_SIZE 32
   const void *gnutls_session_get_server_random (gnutls_session_t session);
   const void *gnutls_session_get_client_random (gnutls_session_t session);
   const void *gnutls_session_get_master_secret (gnutls_session_t session);
 
+  typedef void
+  (*gnutls_finished_callback_func) (gnutls_session_t session,
+				    const void *finished,
+				    size_t len);
+  void
+  gnutls_session_set_finished_function (gnutls_session_t session,
+					gnutls_finished_callback_func
+					finished_func);
+
 /* checks if this session is a resumed one 
  */
   int gnutls_session_is_resumed (gnutls_session_t session);
@@ -699,13 +755,11 @@ extern "C"
 					   gnutls_x509_crt_fmt_t type);
 
   void gnutls_certificate_send_x509_rdn_sequence (gnutls_session_t session,
-                                             int status);
-                                             
+						  int status);
 
-  extern int
-    gnutls_certificate_set_x509_simple_pkcs12_file
-    (gnutls_certificate_credentials_t res, const char *pkcs12file,
-     gnutls_x509_crt_fmt_t type, const char *password);
+  int gnutls_certificate_set_x509_simple_pkcs12_file
+  (gnutls_certificate_credentials_t res, const char *pkcs12file,
+   gnutls_x509_crt_fmt_t type, const char *password);
 
 /* New functions to allow setting already parsed X.509 stuff.
  */
@@ -754,14 +808,13 @@ extern "C"
   typedef void (*gnutls_free_function) (void *);
   typedef void *(*gnutls_realloc_function) (void *, size_t);
 
-  extern void
-    gnutls_global_set_mem_functions (gnutls_alloc_function gt_alloc_func,
-				     gnutls_alloc_function
-				     gt_secure_alloc_func,
-				     gnutls_is_secure_function
-				     gt_is_secure_func,
-				     gnutls_realloc_function gt_realloc_func,
-				     gnutls_free_function gt_free_func);
+  void gnutls_global_set_mem_functions (gnutls_alloc_function gt_alloc_func,
+					gnutls_alloc_function
+					gt_secure_alloc_func,
+					gnutls_is_secure_function
+					gt_is_secure_func,
+					gnutls_realloc_function gt_realloc_func,
+					gnutls_free_function gt_free_func);
 
 /* For use in callbacks */
   extern gnutls_alloc_function gnutls_malloc;
@@ -896,12 +949,15 @@ extern "C"
 
   const char *gnutls_srp_server_get_username (gnutls_session_t session);
 
-  extern int gnutls_srp_verifier (const char *username,
-				  const char *password,
-				  const gnutls_datum_t * salt,
-				  const gnutls_datum_t * generator,
-				  const gnutls_datum_t * prime,
-				  gnutls_datum_t * res);
+  extern void gnutls_srp_set_prime_bits (gnutls_session_t session,
+					 unsigned int bits);
+
+  int gnutls_srp_verifier (const char *username,
+			   const char *password,
+			   const gnutls_datum_t * salt,
+			   const gnutls_datum_t * generator,
+			   const gnutls_datum_t * prime,
+			   gnutls_datum_t * res);
 
 /* The static parameters defined in draft-ietf-tls-srp-05
  * Those should be used as input to gnutls_srp_verifier().
